@@ -1,7 +1,7 @@
 
 /*
  *  agCgi.c
- *  $Id: agCgi.c,v 1.13 2004/02/02 03:31:50 bkorb Exp $
+ *  $Id: agCgi.c,v 4.4 2005/01/24 00:00:30 bkorb Exp $
  *
  *  This is a CGI wrapper for AutoGen.  It will take POST-method
  *  name-value pairs and emit AutoGen definitions to a spawned
@@ -9,7 +9,7 @@
  */
 
 /*
- *  AutoGen-cgi copyright 2001-2004 Bruce Korb
+ *  AutoGen-cgi copyright 2001-2005 Bruce Korb
  *
  *  AutoGen-cgi is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -77,9 +77,13 @@ static const char zOops[] =
 "Content-type: text/plain\n\n"
 "AutoGen form processing error:\n";
 
-static char* parseInput( char* pzSrc, int len );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static char*
+parseInput( char* pzSrc, int len );
+/* = = = END-STATIC-FORWARD = = = */
 
-EXPORT void
+LOCAL void
 loadCgi( void )
 {
     /*
@@ -161,7 +165,7 @@ loadCgi( void )
     }
 
     pBaseCtx->lineNo     = 1;
-    pBaseCtx->pzFileName = "@@ CGI Definitions @@";
+    pBaseCtx->pzCtxFname = "@@ CGI Definitions @@";
     pBaseCtx->pzScan     = pBaseCtx->pzData;
 }
 
