@@ -1,12 +1,12 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 4.1 2005/01/01 00:12:17 bkorb Exp $
+ *  $Id: agUtils.c,v 4.4 2005/02/14 17:03:36 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,7 +25,11 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC tCC* skipQuote( tCC* pzQte );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tCC*
+skipQuote( tCC* pzQte );
+/* = = = END-STATIC-FORWARD = = = */
 
 #ifndef HAVE_STRLCPY
 size_t
@@ -56,7 +60,7 @@ strlcpy( char* dest, tCC* src, size_t n )
 #endif
 
 
-EXPORT char*
+LOCAL char*
 aprf( const char* pzFmt, ... )
 {
     char* pz;
@@ -77,7 +81,7 @@ aprf( const char* pzFmt, ... )
 }
 
 
-EXPORT void
+LOCAL void
 doOptions( int arg_ct, char** arg_vec )
 {
     /*
@@ -193,7 +197,7 @@ doOptions( int arg_ct, char** arg_vec )
 }
 
 
-EXPORT tCC*
+LOCAL tCC*
 getDefine( tCC* pzDefName )
 {
     tCC**   ppz;
@@ -222,116 +226,6 @@ getDefine( tCC* pzDefName )
 }
 
 
-EXPORT unsigned int
-doEscapeChar( tCC* pzIn, char* pRes )
-{
-    unsigned int  res = 1;
-
-    switch (*pRes = *pzIn++) {
-    case NUL:         /* NUL - end of input string */
-    case '\n':        /* NL  - Omit newline        */
-        return 0;
-
-    case 't':
-        *pRes = '\t'; /* TAB */
-        break;
-    case 'n':
-        *pRes = '\n'; /* NEWLINE (LineFeed) */
-        break;
-    case 'f':
-        *pRes = '\f'; /* FormFeed (NewPage) */
-        break;
-    case 'r':
-        *pRes = '\r'; /* Carriage Return    */
-        break;
-    case 'v':
-        *pRes = '\v'; /* Vertical Tab       */
-        break;
-    case 'b':
-        *pRes = '\b'; /* backspace          */
-        break;
-    case 'a':
-        *pRes = '\a'; /* Bell               */
-        break;
-
-    case 'x':         /* HEX Escape       */
-        if (isxdigit( *pzIn ))  {
-            unsigned int  val;
-            unsigned char ch = *pzIn++;
-
-            if ((ch >= 'A') && (ch <= 'F'))
-                val = 10 + (ch - 'A');
-            else if ((ch >= 'a') && (ch <= 'f'))
-                val = 10 + (ch - 'a');
-            else val = ch - '0';
-
-            ch = *pzIn;
-
-            if (! isxdigit( ch )) {
-                *pRes = val;
-                res   = 2;
-                break;
-            }
-            val <<= 4;
-            if ((ch >= 'A') && (ch <= 'F'))
-                val += 10 + (ch - 'A');
-            else if ((ch >= 'a') && (ch <= 'f'))
-                val += 10 + (ch - 'a');
-            else val += ch - '0';
-
-            res = 3;
-            *pRes = val;
-        }
-        break;
-
-    default:
-        /*
-         *  IF the character copied was an octal digit,
-         *  THEN set the output character to an octal value
-         */
-        if (isdigit( *pRes ) && (*pRes < '8'))  {
-            unsigned int  val = *pRes - '0';
-            unsigned char ch  = *pzIn++;
-
-            /*
-             *  IF the second character is *not* an octal digit,
-             *  THEN save the value and bail
-             */
-            if ((ch < '0') || (ch > '7')) {
-                *pRes = val;
-                break;
-            }
-
-            val = (val<<3) + (ch - '0');
-            ch  = *pzIn;
-            res = 2;
-
-            /*
-             *  IF the THIRD character is *not* an octal digit,
-             *  THEN save the value and bail
-             */
-            if ((ch < '0') || (ch > '7')) {
-                *pRes = val;
-                break;
-            }
-
-            /*
-             *  IF the new value would not be too large,
-             *  THEN add on the third and last character value
-             */
-            if ((val<<3) < 0xFF) {
-                val = (val<<3) + (ch - '0');
-                res = 3;
-            }
-
-            *pRes = val;
-            break;
-        }
-    }
-
-    return res;
-}
-
 /*
  *  The following routine scans over quoted text, shifting
  *  it in the process and eliminating the starting quote,
@@ -340,7 +234,7 @@ doEscapeChar( tCC* pzIn, char* pRes )
  *  The quote character is whatever character the argument
  *  is pointing at when this procedure is called.
  */
-EXPORT char*
+LOCAL char*
 spanQuote( char* pzQte )
 {
     char  q = *pzQte;          /*  Save the quote character type */
@@ -353,19 +247,9 @@ spanQuote( char* pzQte )
 
         case '\\':
             if (q != '\'') {
-                unsigned int ct = doEscapeChar( pzQte, p-1 );
-                /*
-                 *  IF the advance is zero,
-                 *  THEN we either have end of string (caught above),
-                 *       or we have an escaped new-line,
-                 *       which is to be ignored.
-                 *  ELSE advance the quote scanning pointer by ct
-                 */
-                if (ct == 0) {
-                    p--;     /* move destination back one character */
-                    pzQte++; /* skip over new-line character        */
-                } else
-                    pzQte += ct;
+                int ct = ao_string_cook_escape_char(pzQte, p-1, 0x7F);
+                if (p[-1] == 0x7F)  p--;
+                pzQte += ct;
 
             } else {
                 switch (*pzQte) {
@@ -391,7 +275,7 @@ spanQuote( char* pzQte )
  *  The quote character is whatever character the argument
  *  is pointing at when this procedure is called.
  */
-STATIC tCC*
+static tCC*
 skipQuote( tCC* pzQte )
 {
     char  q = *pzQte++;        /*  Save the quote character type */
@@ -416,18 +300,8 @@ skipQuote( tCC* pzQte )
 
             } else {
                 char p[10];  /* provide a scratch pad for escape processing */
-                unsigned int ct = doEscapeChar( pzQte, p );
-                /*
-                 *  IF the advance is zero,
-                 *  THEN we either have end of string (caught above),
-                 *       or we have an escaped new-line,
-                 *       which is to be ignored.
-                 *  ELSE advance the quote scanning pointer by ct
-                 */
-                if (ct == 0) {
-                    pzQte++; /* skip over new-line character        */
-                } else
-                    pzQte += ct;
+                int ct = ao_string_cook_escape_char( pzQte, p, 0x7F );
+                pzQte += ct;
             } /* if (q == '\'')      */
         }     /* switch (*pzQte++)   */
     }         /* while (*pzQte != q) */
@@ -436,7 +310,7 @@ skipQuote( tCC* pzQte )
 }
 
 
-EXPORT tCC*
+LOCAL tCC*
 skipScheme( tCC* pzSrc,  tCC* pzEnd )
 {
     int  level = 0;
@@ -461,7 +335,7 @@ skipScheme( tCC* pzSrc,  tCC* pzEnd )
 }
 
 
-EXPORT tCC*
+LOCAL tCC*
 skipExpression( tCC* pzSrc, size_t len )
 {
     tCC* pzEnd = pzSrc + len;
