@@ -1,12 +1,12 @@
 
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 1.30 2004/10/02 22:12:56 bkorb Exp $
+ *  $Id: defDirect.c,v 4.5 2005/01/26 01:11:06 bkorb Exp $
  *  This module processes definition file directives.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -30,11 +30,64 @@ tSCC zNoMatch[]   = "Definition error:  in %s line %d, "
                     "#%s no matching start/if directive\n";
 tSCC zCheckList[] = "\n#";
 
-STATIC int  ifdefLevel = 0;
-STATIC teDirectives findDirective( char* pzDirName );
-STATIC teDirectives findDirective( char* pzDirName );
-STATIC char* skipToEndif( char* pzScan );
-STATIC char* skipToElseEnd( char* pzScan );
+static int  ifdefLevel = 0;
+
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static teDirectives
+findDirective( char* pzDirName );
+
+static char*
+skipToEndif( char* pzScan );
+
+static char*
+skipToElseEnd( char* pzScan );
+
+static char*
+doDir_IGNORE( char* pzArg, char* pzScan );
+
+static char*
+doDir_define( char* pzArg, char* pzScan );
+
+static char*
+doDir_elif( char* pzArg, char* pzScan );
+
+static char*
+doDir_else( char* pzArg, char* pzScan );
+
+static char*
+doDir_endif( char* pzArg, char* pzScan );
+
+static char*
+doDir_endshell( char* pzArg, char* pzScan );
+
+static char*
+doDir_error( char* pzArg, char* pzScan );
+
+static char*
+doDir_if( char* pzArg, char* pzScan );
+
+static char*
+doDir_ifdef( char* pzArg, char* pzScan );
+
+static char*
+doDir_ifndef( char* pzArg, char* pzScan );
+
+static char*
+doDir_include( char* pzArg, char* pzScan );
+
+static char*
+doDir_line( char* pzArg, char* pzScan );
+
+static char*
+doDir_option( char* pzArg, char* pzScan );
+
+static char*
+doDir_shell( char* pzArg, char* pzScan );
+
+static char*
+doDir_undef( char* pzArg, char* pzScan );
+/* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -46,7 +99,7 @@ STATIC char* skipToElseEnd( char* pzScan );
  *  Decide what to do and return a pointer to the character
  *  where scanning is to resume.
  */
-EXPORT char*
+LOCAL char*
 processDirective( char* pzScan )
 {
     const tDirTable* pTbl  = dirTable;
@@ -141,7 +194,7 @@ processDirective( char* pzScan )
  *  count if it is a bogus name.
  */
 
-STATIC teDirectives
+static teDirectives
 findDirective( char* pzDirName )
 {
     teDirectives res = (teDirectives)0;
@@ -166,7 +219,7 @@ findDirective( char* pzDirName )
         }
 
         fprintf( pfTrace, "WARNING:  in %s on line %d unknown directive:\n"
-                 "\t#%s\n", pCurCtx->pzFileName, pCurCtx->lineNo, pzDirName );
+                 "\t#%s\n", pCurCtx->pzCtxFname, pCurCtx->lineNo, pzDirName );
 
         if (ch != NUL)
             pzDirName[32] = ch;
@@ -185,7 +238,7 @@ findDirective( char* pzDirName )
  *  accepting the preceeding text) or when encountering a "#if*def"
  *  while skipping a block of text due to a failed test.
  */
-STATIC char*
+static char*
 skipToEndif( char* pzScan )
 {
     for (;;) {
@@ -200,7 +253,7 @@ skipToEndif( char* pzScan )
         else {
             pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
-                AG_ABEND( aprf( zNoEndif, pCurCtx->pzFileName,
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
                                 pCurCtx->lineNo ));
 
             pzScan = pz + STRSIZE( zCheckList );
@@ -245,7 +298,7 @@ skipToEndif( char* pzScan )
  *  "#elif*def".  We do this when we are skipping code due to a failed
  *  "#if*def" test.
  */
-STATIC char*
+static char*
 skipToElseEnd( char* pzScan )
 {
     for (;;) {
@@ -260,7 +313,7 @@ skipToElseEnd( char* pzScan )
         else {
             pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
-                AG_ABEND( aprf( zNoEndif, pCurCtx->pzFileName,
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
                                 pCurCtx->lineNo ));
 
             pzScan = pz + STRSIZE( zCheckList );
@@ -323,7 +376,7 @@ skipToElseEnd( char* pzScan )
  *  needs or may take arguments (e.g. '#define'), then there should
  *  also be an 'arg:' section describing the argument(s).
  */
-STATIC char*
+static char*
 doDir_IGNORE( char* pzArg, char* pzScan )
 {
     return pzScan;
@@ -348,7 +401,7 @@ doDir_IGNORE( char* pzArg, char* pzScan )
  *  After the definitions file has been processed, any remaining entries
  *  in the define list will be added to the environment.
 =*/
-STATIC char*
+static char*
 doDir_define( char* pzArg, char* pzScan )
 {
     char*  pzName = pzArg;
@@ -375,16 +428,19 @@ doDir_define( char* pzArg, char* pzScan )
      *       directive itself, giving us the space needed.
      */
     if (! isspace( *pzArg )) {
-        pzName--;
+        char* pzS = pzName;
+        char* pzD = --pzName;
+
         *pzArg = NUL;
-        strcpy( pzName, pzName+1 );
-        strcat( pzName, "=" );
+        while ((*(pzD++) = *(pzS++)) != NUL)   ;
+        pzD[-1] = '=';
+        pzD[ 0] = NUL;
 
     } else {
         /*
          *  Otherwise, insert the '=' and move any data up against it.
-         *  We only accept one space separated token.  We are not
-         *  ANSI-C compliant.  ;-)
+         *  We only accept one name-type, space separated token.
+         *  We are not ANSI-C.  ;-)
          */
         char*  pz = pzArg+1;
         *pzArg++ = '=';
@@ -393,7 +449,7 @@ doDir_define( char* pzArg, char* pzScan )
         for (;;) {
             if ((*pzArg++ = *pz++) == NUL)
                 break;
-            if (isspace( *pz )) {
+            if (! ISNAMECHAR( *pz )) {
                 *pzArg = NUL;
                 break;
             }
@@ -412,13 +468,13 @@ doDir_define( char* pzArg, char* pzScan )
  *  otherwise it will generate an error.
  *  It will be ignored.
 =*/
-STATIC char*
+static char*
 doDir_elif( char* pzArg, char* pzScan )
 {
     tSCC z[] =
         "`#elif' directive encountered out of context\n\tin %s on line %d\n";
 
-    AG_ABEND( aprf( z, pCurCtx->pzFileName, pCurCtx->lineNo ));
+    AG_ABEND( aprf( z, pCurCtx->pzCtxFname, pCurCtx->lineNo ));
     /* NOTREACHED */
     return NULL;
 }
@@ -431,11 +487,11 @@ doDir_elif( char* pzArg, char* pzScan )
  *  If it follows the @code{#if}, then it will be ignored.  Otherwise,
  *  it will change the processing state to the reverse of what it was.
 =*/
-STATIC char*
+static char*
 doDir_else( char* pzArg, char* pzScan )
 {
     if (--ifdefLevel < 0)
-        AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+        AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
                         "else" ));
 
     return skipToEndif( pzScan );
@@ -448,11 +504,11 @@ doDir_else( char* pzArg, char* pzScan )
  *  This must follow an @code{#if}, @code{#ifdef} or @code{#ifndef}.
  *  In all cases, this will resume normal processing of text.
 =*/
-STATIC char*
+static char*
 doDir_endif( char* pzArg, char* pzScan )
 {
     if (--ifdefLevel < 0)
-        AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+        AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
                         "endif" ));
 
     return pzScan;
@@ -464,14 +520,14 @@ doDir_endif( char* pzArg, char* pzScan )
  *  text:
  *  Ends the text processed by a command shell into autogen definitions.
 =*/
-STATIC char*
+static char*
 doDir_endshell( char* pzArg, char* pzScan )
 {
     /*
      *  In actual practice, the '#endshell's must be consumed inside
      *  the 'doDir_shell()' procedure.
      */
-    AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+    AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
                     "endshell" ));
     /* NOTREACHED */
     return NULL;
@@ -486,11 +542,11 @@ doDir_endshell( char* pzArg, char* pzScan )
  *  This directive will cause AutoGen to stop processing
  *  and exit with a status of EXIT_FAILURE.
 =*/
-STATIC char*
+static char*
 doDir_error( char* pzArg, char* pzScan )
 {
     AG_ABEND( aprf( "#error directive -- in %s on line %d\n\t%s\n",
-                    pCurCtx->pzFileName, pCurCtx->lineNo, pzArg ));
+                    pCurCtx->pzCtxFname, pCurCtx->lineNo, pzArg ));
     /* NOTREACHED */
     return NULL;
 }
@@ -510,7 +566,7 @@ doDir_error( char* pzArg, char* pzScan )
  *  @code{#if} expressions are not analyzed.  @strong{Everything} from here
  *  to the matching @code{#endif} is skipped.
 =*/
-STATIC char*
+static char*
 doDir_if( char* pzArg, char* pzScan )
 {
     return skipToEndif( pzScan );
@@ -526,7 +582,7 @@ doDir_if( char* pzArg, char* pzScan )
  *  processed only if there is a corresponding @code{-Dname} command line
  *  option.
 =*/
-STATIC char*
+static char*
 doDir_ifdef( char* pzArg, char* pzScan )
 {
     if (getDefine( pzArg ) == NULL)
@@ -545,7 +601,7 @@ doDir_ifdef( char* pzArg, char* pzScan )
  *  processed only if there is @strong{not} a corresponding @code{-Dname}
  *  command line option or there was a canceling @code{-Uname} option.
 =*/
-STATIC char*
+static char*
 doDir_ifndef( char* pzArg, char* pzScan )
 {
     if (getDefine( pzArg ) != NULL)
@@ -565,7 +621,7 @@ doDir_ifndef( char* pzArg, char* pzScan )
  *  double quotes or angle brackets (as in a C program), then the
  *  include is ignored.
 =*/
-STATIC char*
+static char*
 doDir_include( char* pzArg, char* pzScan )
 {
     tSCC*      apzSfx[] = { "def", NULL };
@@ -628,7 +684,7 @@ doDir_include( char* pzArg, char* pzScan )
      */
     pCtx->pCtx       = pCurCtx;
     pCurCtx          = pCtx;
-    AGDUPSTR( pCtx->pzFileName, zFullName, "def file name" );
+    AGDUPSTR( pCtx->pzCtxFname, zFullName, "def file name" );
 
     pCtx->pzScan     =
     pCtx->pzData     =
@@ -675,7 +731,7 @@ doDir_include( char* pzArg, char* pzScan )
  *  file and approximate line number of any errors found in extracted
  *  definitions.
 =*/
-STATIC char*
+static char*
 doDir_line( char* pzArg, char* pzScan )
 {
     /*
@@ -702,8 +758,8 @@ doDir_line( char* pzArg, char* pzScan )
             return pzScan;
         *pz = NUL;
     }
-    AGFREE( (void*)pCurCtx->pzFileName );
-    AGDUPSTR( pCurCtx->pzFileName, pzArg, "#line file name" );
+
+    AGDUPSTR( pCurCtx->pzCtxFname, pzArg, "#line file name" );
 
     return pzScan;
 }
@@ -732,7 +788,7 @@ doDir_line( char* pzArg, char* pzScan )
  *  directories supplied in this way will be searched before any supplied on
  *  the command line.
 =*/
-STATIC char*
+static char*
 doDir_option( char* pzArg, char* pzScan )
 {
     optionLoadLine( &autogenOptions, pzArg );
@@ -754,7 +810,7 @@ doDir_option( char* pzArg, char* pzScan )
  *  process that handles the back-quoted @code{`} text.
  *  @strong{CAUTION}@:  let not your @code{$SHELL} be @code{csh}.
 =*/
-STATIC char*
+static char*
 doDir_shell( char* pzArg, char* pzScan )
 {
     tSCC       zShellText[] = "Computed Definitions";
@@ -780,7 +836,7 @@ doDir_shell( char* pzArg, char* pzScan )
     pzScan = strstr( pzScan, zEndShell );
     if (pzScan == NULL)
         AG_ABEND( aprf( "Missing #endshell after '#shell' in %s on line %d\n",
-                        pCurCtx->pzFileName, pCurCtx->lineNo ));
+                        pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
     *pzScan = NUL;
 
@@ -827,7 +883,7 @@ doDir_shell( char* pzArg, char* pzScan )
     /*
      *  Set up the rest of the context structure
      */
-    AGDUPSTR( pCtx->pzFileName, zShellText, "shell text" );
+    AGDUPSTR( pCtx->pzCtxFname, zShellText, "shell text" );
     pCtx->pzScan     =
     pCtx->pzData     = (char*)(pCtx+1);
     pCtx->lineNo     = 0;
@@ -846,7 +902,7 @@ doDir_shell( char* pzArg, char* pzScan )
  *  Will remove any entries from the define list
  *  that match the undef name pattern.
 =*/
-STATIC char*
+static char*
 doDir_undef( char* pzArg, char* pzScan )
 {
     SET_OPT_UNDEFINE( pzArg );
