@@ -1,12 +1,12 @@
 
 /*
- *  $Id: defLex.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
+ *  $Id: defLex.c,v 4.5 2005/02/14 17:03:51 bkorb Exp $
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -54,17 +54,26 @@ int    aKeywordTkn[] = { KEYWORD_TABLE };
 
 #define SET_LIT_TKN(t) lastToken = DP_EV_LIT_ ## t; *(pCurCtx->pzScan++) = NUL;
 
-STATIC void  loadScheme( void );
-STATIC void  alist_to_autogen_def( void );
-STATIC char* assembleName( char* pzScan, te_dp_event* pRetVal );
-STATIC char* assembleString( char* pzScan );
-STATIC char* assembleHereString( char* pzScan );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+loadScheme( void );
+
+static void
+alist_to_autogen_def( void );
+
+static char*
+assembleName( char* pzScan, te_dp_event* pRetVal );
+
+static char*
+assembleHereString( char* pzScan );
+/* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *   LEXICAL SCANNER
  */
-EXPORT te_dp_event
+LOCAL te_dp_event
 yylex( void )
 {
     lastToken = DP_EV_INVALID;
@@ -109,7 +118,6 @@ scanAgain:
         {
             tScanCtx* pCX = pCurCtx;
             pCurCtx = pCurCtx->pCtx;
-            AGFREE( (void*)pCX->pzFileName );
             pCX->pCtx = pDoneCtx;
             pDoneCtx  = pCX;
         }
@@ -138,10 +146,12 @@ scanAgain:
     case '\'':
     case '"':
     {
-        char* pz = assembleString( pCurCtx->pzScan );
+        char* pz = ao_string_cook( pCurCtx->pzScan, &(pCurCtx->lineNo));
         if (pz == NULL)
             goto NUL_error;
 
+        pz_token = pCurCtx->pzScan;
+
         lastToken = DP_EV_STRING;
         pCurCtx->pzScan = pz;
         break;
@@ -196,11 +206,13 @@ scanAgain:
 
     case '`':
     {
-        char*   pz = assembleString( pCurCtx->pzScan );
+        char* pz = ao_string_cook( pCurCtx->pzScan, &(pCurCtx->lineNo));
 
         if (pz == NULL)
             goto NUL_error;
 
+        pz_token = pCurCtx->pzScan;
+
         pCurCtx->pzScan = pz;
 
         if (pzShellProgram == NULL)
@@ -260,7 +272,7 @@ scanAgain:
 NUL_error:
 
     AG_ABEND( aprf( zErrMsg, pzProg, "unterminated quote in definition",
-                    pCurCtx->pzFileName, pCurCtx->lineNo ));
+                    pCurCtx->pzCtxFname, pCurCtx->lineNo ));
     return DP_EV_INVALID;
 
 lex_done:
@@ -284,7 +296,7 @@ lex_done:
 }
 
 
-EXPORT void
+LOCAL void
 yyerror( char* s )
 {
     tSCC zErrTkn[] = "%s:  ``%s''\n";
@@ -314,12 +326,12 @@ yyerror( char* s )
                     "\t[[...<error-text>]] %s\n\n"
                     "Likely causes:  a mismatched quote, a value that needs "
                     "quoting,\n\t\tor a missing semi-colon\n",
-                    s, pCurCtx->pzFileName, pCurCtx->lineNo, pz,
+                    s, pCurCtx->pzCtxFname, pCurCtx->lineNo, pz,
                     pCurCtx->pzScan ));
 }
 
 
-STATIC void
+static void
 loadScheme( void )
 {
     char*    pzText    = pCurCtx->pzScan;
@@ -335,7 +347,7 @@ loadScheme( void )
     *pzEnd = NUL;
     procState = PROC_STATE_GUILE_PRELOAD;
     res = ag_scm_c_eval_string_from_file_line(
-        pzText, pCurCtx->pzFileName, pCurCtx->lineNo );
+        pzText, pCurCtx->pzCtxFname, pCurCtx->lineNo );
     procState = PROC_STATE_LOAD_DEFS;
     *pzEnd = endCh;
 
@@ -362,7 +374,7 @@ loadScheme( void )
  *  process a single scheme expression, yielding text that gets processed
  *  into AutoGen definitions.
  */
-STATIC void
+static void
 alist_to_autogen_def( void )
 {
     tSCC   zSchemeText[] = "Scheme Computed Definitions";
@@ -391,7 +403,7 @@ alist_to_autogen_def( void )
      */
     procState = PROC_STATE_GUILE_PRELOAD;
     res = ag_scm_c_eval_string_from_file_line(
-        pzText, pCurCtx->pzFileName, pCurCtx->lineNo );
+        pzText, pCurCtx->pzCtxFname, pCurCtx->lineNo );
 
     /*
      *  The result *must* be a string, or we choke.
@@ -417,7 +429,7 @@ alist_to_autogen_def( void )
     /*
      *  Set up the rest of the context structure
      */
-    AGDUPSTR( pCtx->pzFileName, zSchemeText, "scheme text" );
+    AGDUPSTR( pCtx->pzCtxFname, zSchemeText, "scheme text" );
     pCtx->pzScan = \
     pCtx->pzData = (char*)(pCtx+1);
     pCtx->lineNo = 0;
@@ -438,7 +450,7 @@ alist_to_autogen_def( void )
  *  It may be a number, a name, a keyword or garbage.
  *  Figure out which.
  */
-STATIC char*
+static char*
 assembleName( char* pzScan, te_dp_event* pRetVal )
 {
     /*
@@ -502,7 +514,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
             if (pz == (unsigned char*)pzScan)
                 AG_ABEND( aprf( "%s Error: Invalid input char '%c' "
                                 "in %s on line %d\n", pzProg, *pzScan,
-                                pCurCtx->pzFileName, pCurCtx->lineNo ));
+                                pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
             *pRetVal = DP_EV_VAR_NAME;
         } else {
@@ -549,7 +561,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
  *  A quoted string has been found.
  *  Find the end of it and compress any escape sequences.
  */
-STATIC char*
+static char*
 assembleHereString( char* pzScan )
 {
     ag_bool  trimTabs = AG_FALSE;
@@ -571,7 +583,7 @@ assembleHereString( char* pzScan )
     while (isspace( *pzScan )) {
         if (*pzScan++ == '\n')
             AG_ABEND( aprf( zErrMsg, pzProg, "HereString missing the mark",
-                            pCurCtx->pzFileName, pCurCtx->lineNo ));
+                            pCurCtx->pzCtxFname, pCurCtx->lineNo ));
     }
 
     /*
@@ -583,13 +595,13 @@ assembleHereString( char* pzScan )
             if (++markLen >= sizeof(zMark))
                 AG_ABEND( aprf( zErrMsg, pzProg, "HereString mark "
                                 STR( MAX_HEREMARK_LEN ) " or more chars",
-                                pCurCtx->pzFileName, pCurCtx->lineNo ));
+                                pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
             *(pz++) = *(pzScan++);
         }
         if (markLen == 0)
             AG_ABEND( aprf( zErrMsg, pzProg, "HereString missing the mark",
-                            pCurCtx->pzFileName, pCurCtx->lineNo ));
+                            pCurCtx->pzCtxFname, pCurCtx->lineNo ));
         *pz = NUL;
     }
 
@@ -602,11 +614,12 @@ assembleHereString( char* pzScan )
     pzScan = strchr( pzScan, '\n' );
     if (pzScan == NULL)
         AG_ABEND( aprf( zErrMsg, pzProg, "Unterminated HereString",
-                        pCurCtx->pzFileName, pCurCtx->lineNo ));
+                        pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
     /*
      *  And skip the first new line + conditionally skip tabs
      */
+    pCurCtx->lineNo++;
     pzScan++;
 
     if (trimTabs)
@@ -628,7 +641,7 @@ assembleHereString( char* pzScan )
 
             case NUL:
                 AG_ABEND( aprf( zErrMsg, pzProg, "Unterminated HereString",
-                                pCurCtx->pzFileName, pCurCtx->lineNo ));
+                                pCurCtx->pzCtxFname, pCurCtx->lineNo ));
             }
         } lineDone:;
 
@@ -645,140 +658,6 @@ assembleHereString( char* pzScan )
 
     return pzScan + markLen;
 }
-
-
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *  A quoted string has been found.
- *  Find the end of it and compress any escape sequences.
- */
-STATIC char*
-assembleString( char* pzScan )
-{
-    char  q = *(pzScan++);
-
-    /*
-     *  It is a quoted string.  Process the escape sequence characters
-     *  (in the set "abfnrtv") and make sure we find a closing quote.
-     */
-    char* pzD = pzScan;
-    char* pzS = pzScan;
-
-    pz_token = pzD;
-
-    for (;;) {
-        /*
-         *  IF the next character is the quote character, THEN we may end the
-         *  string.  We end it unless the next non-blank character *after* the
-         *  string happens to also be a quote.  If it is, then we will change
-         *  our quote character to the new quote character and continue
-         *  condensing text.
-         */
-        while (*pzS == q) {
-            *pzD = NUL;
-        scan_for_quote:
-            while (isspace(*(++pzS)))
-                if (*pzS == '\n')
-                    pCurCtx->lineNo++;
-
-            /*
-             *  IF the next character is a quote character,
-             *  THEN we will concatenate the strings.
-             */
-            switch (*pzS) {
-            case '"':
-            case '\'':
-                break;
-
-            case '/':
-                /*
-                 *  Allow for a comment embedded in the concatenated string.
-                 */
-                switch (pzS[1]) {
-                default:  return pzS;
-                case '/':
-                    /*
-                     *  Skip to end of line
-                     */
-                    for (;;) {
-                        char ch = *++pzS;
-                        switch (ch) {
-                        case '\n': goto scan_for_quote;
-                        case '\0': return pzS;
-                        default:   break;
-                        }
-                    }
-                case '*':
-                    /*
-                     *  Skip to terminating star slash
-                     */
-                    pzS = strstr( pzS+2, "*/" );
-                    if (pzS == NULL)
-                        return (char*)zNil;
-                    pzS++;
-                    goto scan_for_quote;
-                }
-
-            case '#':
-                /*
-                 *  IF the next character is a directive,
-                 *  THEN ensure it is in the first column!!
-                 */
-                if (pzS[-1] != '\n')
-                    return assembleName( pzS, &lastToken );
-                /* FALLTHROUGH */
-
-            default:
-                return pzS;
-            }
-            q = *(pzS++);
-        }
-
-        switch (*(pzD++) = *(pzS++)) {
-        case NUL:
-            return NULL;
-
-        case '\n':
-            pCurCtx->lineNo++;
-            break;
-
-        case '\\':
-            /*
-             *  IF we are escaping a new line,
-             *  THEN drop both the escape and the newline from
-             *       the result string.
-             */
-            if (*pzS == '\n') {
-                pzS++;
-                pzD--;
-                pCurCtx->lineNo++;
-            }
-
-            /*
-             *  ELSE IF the quote character is '"' or '`',
-             *  THEN we do the full escape character processing
-             */
-            else if (q != '\'') {
-                int ct = doEscapeChar( pzS, pzD-1 );
-                if (ct == 0)
-                    return NULL;
-
-                pzS += ct;
-            }     /* if (q != '\'')                  */
-
-            /*
-             *  OTHERWISE, we only process "\\", "\'" and "\#" sequences.
-             *  The latter only to easily hide preprocessing directives.
-             */
-            else switch (*pzS) {
-            case '\\':
-            case '\'':
-            case '#':
-                pzD[-1] = *pzS++;
-            }
-        }     /* switch (*(pzD++) = *(pzS++))    */
-    }         /* for (;;)                        */
-}
 /*
  * Local Variables:
  * mode: C
