@@ -1,12 +1,12 @@
 
 /*
- *  $Id: expOutput.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
+ *  $Id: expOutput.c,v 4.4 2005/03/13 19:51:31 bkorb Exp $
  *
  *  This module implements the output file manipulation function
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -37,16 +37,18 @@ typedef struct {
     tFpStack*   pOutDesc;
 } tSuspendName;
 
-STATIC int            suspendCt   = 0;
-STATIC int            suspAllocCt = 0;
-STATIC tSuspendName*  pSuspended  = NULL;
-STATIC int            outputDepth = 1;
+static int            suspendCt   = 0;
+static int            suspAllocCt = 0;
+static tSuspendName*  pSuspended  = NULL;
+static int            outputDepth = 1;
 
-STATIC void addWriteAccess( char* pzFileName );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+addWriteAccess( char* pzFileName );
+/* = = = END-STATIC-FORWARD = = = */
 
-
-
-EXPORT void
+LOCAL void
 removeWriteAccess( int fd )
 {
     struct stat    sbuf;
@@ -76,7 +78,7 @@ removeWriteAccess( int fd )
     fchmod( fd, sbuf.st_mode & S_IAMB );
 }
 
-STATIC void
+static void
 addWriteAccess( char* pzFileName )
 {
     struct stat    sbuf;
@@ -375,7 +377,7 @@ ag_scm_out_push_new( SCM new_file )
          *  Otherwise, anonymous output without --no-fmemopen being selected
          *  will get us here.
          */
-        p->pFile  = fmemopen( NULL, 0, "wb+" );
+        p->pFile  = ag_fmemopen( NULL, 0, "wb+" );
         pzNewFile = "in-mem buffer";
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
     }
