@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expPrint.c,v 1.42 2004/08/08 15:10:50 bkorb Exp $
+ *  $Id: expPrint.c,v 4.3 2005/01/24 00:00:32 bkorb Exp $
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -10,7 +10,7 @@
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -29,19 +29,28 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC sigjmp_buf printJumpEnv;
-STATIC void   printFault( int sig );
-STATIC ssize_t safePrintf( char** pzBuf, char* pzFmt, void** argV );
+static sigjmp_buf printJumpEnv;
+static void   printFault( int sig );
+static ssize_t safePrintf( char** pzBuf, char* pzFmt, void** argV );
 tSCC pzFormatName[] = "format";
 
-STATIC void
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+printFault( int sig );
+
+static ssize_t
+safePrintf( char** ppzBuf, char* pzFmt, void** argV );
+/* = = = END-STATIC-FORWARD = = = */
+
+static void
 printFault( int sig )
 {
     siglongjmp( printJumpEnv, sig );
 }
 
 
-STATIC ssize_t
+static ssize_t
 safePrintf( char** ppzBuf, char* pzFmt, void** argV )
 {
     tSCC zBadArgs[]  = "Bad args to sprintf";
@@ -97,7 +106,7 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
 }
 
 
-EXPORT SCM
+LOCAL SCM
 run_printf( char* pzFmt, int len, SCM alist )
 {
     SCM     res;
