@@ -1,13 +1,13 @@
 
 /*
  *  expString.c
- *  $Id: expString.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
+ *  $Id: expString.c,v 4.5 2005/02/14 17:03:52 bkorb Exp $
  *  This module implements expression functions that
  *  manipulate string values.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -26,7 +26,34 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC SCM
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static SCM
+makeString( tCC*    pzText,
+            tCC*    pzNewLine,
+            size_t  newLineSize );
+
+static SCM
+shell_stringify( SCM obj, char qt );
+
+static void
+do_substitution(
+    tCC*        pzStr,
+    scm_sizet   strLen,
+    SCM         match,
+    SCM         repl,
+    char**      ppzRes,
+    scm_sizet*  pResLen );
+
+static void
+do_multi_subs(
+    char**      ppzStr,
+    scm_sizet*  pStrLen,
+    SCM         match,
+    SCM         repl );
+/* = = = END-STATIC-FORWARD = = = */
+
+static SCM
 makeString( tCC*    pzText,
             tCC*    pzNewLine,
             size_t  newLineSize )
@@ -132,11 +159,6 @@ makeString( tCC*    pzText,
             pzDta += newLineSize;
             break;
 
-        case '\t':
-            *(pzDta++) = '\\';
-            *(pzDta++) = 't';
-            break;
-
         case '\a':
             *(pzDta++) = '\\';
             *(pzDta++) = 'a';
@@ -157,6 +179,11 @@ makeString( tCC*    pzText,
             *(pzDta++) = 'r';
             break;
 
+        case '\t':
+            *(pzDta++) = '\\';
+            *(pzDta++) = 't';
+            break;
+
         case '\v':
             *(pzDta++) = '\\';
             *(pzDta++) = 'v';
@@ -194,7 +221,7 @@ makeString( tCC*    pzText,
 }
 
 
-STATIC SCM
+static SCM
 shell_stringify( SCM obj, char qt )
 {
     char*  pzDta;
@@ -299,7 +326,7 @@ shell_stringify( SCM obj, char qt )
  *  experience, except that we don't use regex-es.  It is straight
  *  text substitution.
  */
-STATIC void
+static void
 do_substitution(
     tCC*        pzStr,
     scm_sizet   strLen,
@@ -362,7 +389,7 @@ do_substitution(
  *  be done in the order found in the tree walk of list values.
  *  The "match" and "repl" trees *must* be identical in structure.
  */
-STATIC void
+static void
 do_multi_subs(
     char**      ppzStr,
     scm_sizet*  pStrLen,
@@ -748,7 +775,7 @@ ag_scm_shellf( SCM fmt, SCM alist )
  *  escaped with a backslash.  Normal shells will reconstitute the
  *  original string.
  *
- *  @strong{NOTE}:  some shells will not correctly handle unusual
+ *  @strong{Notice}:  some shells will not correctly handle unusual
  *  non-printing characters.  This routine works for most reasonably
  *  conventional ASCII strings.
 =*/
