@@ -2,13 +2,13 @@
 /*
  *  tpParse.c
  *
- *  $Id: tpParse.c,v 1.22 2004/02/02 03:31:50 bkorb Exp $
+ *  $Id: tpParse.c,v 4.3 2005/01/24 00:00:34 bkorb Exp $
  *
  *  This module will load a template and return a template structure.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -27,15 +27,20 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC teFuncType whichFunc( tCC** ppzScan );
-STATIC tCC* findMacroEnd( tCC** ppzMark );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static teFuncType
+whichFunc( tCC** ppzScan );
 
+static tCC*
+findMacroEnd( tCC** ppzMark );
+/* = = = END-STATIC-FORWARD = = = */
 
 /*
  *  Return the enumerated function type corresponding
  *  to a name pointed to by the input argument.
  */
-STATIC teFuncType
+static teFuncType
 whichFunc( tCC** ppzScan )
 {
     const char*   pzFuncName = *ppzScan;
@@ -122,7 +127,7 @@ whichFunc( tCC** ppzScan )
 }
 
 
-STATIC tCC*
+static tCC*
 findMacroEnd( tCC** ppzMark )
 {
     tCC* pzMark = *ppzMark + startMacLen;
@@ -156,7 +161,7 @@ findMacroEnd( tCC** ppzMark )
 }
 
 
-EXPORT tMacro*
+LOCAL tMacro*
 parseTemplate( tMacro* pM, tCC** ppzText )
 {
     tCC* pzScan = *ppzText;
