@@ -1,12 +1,12 @@
 
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 4.1 2005/01/01 00:12:34 bkorb Exp $
+ *  $Id: tpProcess.c,v 4.3 2005/01/24 00:00:34 bkorb Exp $
  *  Parse and process the template data descriptions
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,17 +25,23 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC void openOutFile( tOutSpec* pOutSpec, tFpStack* pStk );
+static tFpStack fpRoot = { 0, NULL, NULL, NULL };
 
-STATIC tFpStack fpRoot = { 0, NULL, NULL, NULL };
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+doStdoutTemplate( tTemplate* pTF );
 
+static void
+openOutFile( tOutSpec* pOutSpec, tFpStack* pStk );
+/* = = = END-STATIC-FORWARD = = = */
 
 /*
  *  Generate all the text within a block.  The caller must
  *  know the exact bounds of the block.  "pEnd" actually
  *  must point to the first entry that is *not* to be emitted.
  */
-EXPORT void
+LOCAL void
 generateBlock( tTemplate*   pT,
                tMacro*      pMac,
                tMacro*      pEnd )
@@ -81,7 +87,7 @@ generateBlock( tTemplate*   pT,
 }
 
 
-STATIC void
+static void
 doStdoutTemplate( tTemplate* pTF )
 {
     tSCC zNoSfx[] = "* NONE *";
@@ -156,7 +162,7 @@ doStdoutTemplate( tTemplate* pTF )
 }
 
 
-EXPORT void
+LOCAL void
 processTemplate( tTemplate* pTF )
 {
     forInfo.fi_depth = 0;
@@ -242,7 +248,7 @@ processTemplate( tTemplate* pTF )
 }
 
 
-EXPORT void
+LOCAL void
 closeOutput( ag_bool purge )
 {
     if ((pCurFp->flags & FPF_NOCHMOD) == 0)
@@ -288,7 +294,7 @@ closeOutput( ag_bool purge )
 }
 
 
-STATIC void
+static void
 openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
 {
     tCC*  pzDefFile;
