@@ -1,6 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.1 2005/01/01 00:12:40 bkorb Exp $
+ *  $Id: autoopts.c,v 4.8 2005/03/13 19:51:57 bkorb Exp $
+ *  Time-stamp:      "2005-03-13 08:39:23 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -9,7 +10,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -57,28 +58,23 @@
 
 static const char zNil[] = "";
 
-#define ISNAMECHAR( c )    (isalnum(c) || ((c) == '_') || ((c) == '-'))
-
 #define SKIP_RC_FILES(po) \
     DISABLED_OPT(&((po)->pOptDesc[ (po)->specOptIdx.save_opts+1]))
 
-/* === STATIC PROCS === */
-STATIC tSuccess
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tSuccess
 findOptDesc( tOptions* pOpts, tOptState* pOptState );
 
-STATIC tSuccess
+static tSuccess
 nextOption( tOptions* pOpts, tOptState* pOptState );
 
-STATIC void
-doRcFiles( tOptions* pOpts );
-
-STATIC tSuccess
+static tSuccess
 doPresets( tOptions* pOpts );
 
-STATIC int
+static int
 checkConsistency( tOptions* pOpts );
-
-/* === END STATIC PROCS === */
+/* = = = END-STATIC-FORWARD = = = */
 
 /*
  *  handleOption
@@ -154,7 +150,7 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
              */
             p->optActualValue = pOD->optValue;
             p->optActualIndex = pOD->optIndex;
-            pOptState->flags |= OPTST_EQUIVALENCE;          
+            pOptState->flags |= OPTST_EQUIVALENCE;
         }
 
         /*
@@ -408,7 +404,7 @@ shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState )
  *
  *  Find the option descriptor for the current option
  */
-STATIC tSuccess
+static tSuccess
 findOptDesc( tOptions* pOpts, tOptState* pOptState )
 {
     /*
@@ -501,10 +497,11 @@ findOptDesc( tOptions* pOpts, tOptState* pOptState )
  *  all the state in the state argument so that the option can be skipped
  *  without consequence (side effect).
  */
-STATIC tSuccess
+static tSuccess
 nextOption( tOptions* pOpts, tOptState* pOptState )
 {
     tSuccess res;
+    enum { ARG_NONE, ARG_MAY, ARG_MUST } arg_type = ARG_NONE;
 
     res = findOptDesc( pOpts, pOptState );
     if (! SUCCESSFUL( res ))
@@ -518,10 +515,15 @@ nextOption( tOptions* pOpts, tOptState* pOptState )
      *  Disabled mode option selection also disables option arguments.
      */
     if ((pOptState->flags & OPTST_DISABLED) != 0)
-         pOptState->argType = ARG_NONE;
-    else pOptState->argType = pOptState->pOD->optArgType;
+        arg_type = ARG_NONE;
+    else if (OPTST_GET_ARGTYPE(pOptState->flags) == OPARG_TYPE_NONE)
+        arg_type = ARG_NONE;
+    else if (pOptState->flags & OPTST_ARG_OPTIONAL)
+        arg_type = ARG_MAY;
+    else
+        arg_type = ARG_MUST;
 
-    switch (pOptState->argType) {
+    switch (arg_type) {
     case ARG_MUST:
         /*
          *  An option argument is required.  Long options can either have
@@ -671,11 +673,11 @@ nextOption( tOptions* pOpts, tOptState* pOptState )
  *  DO PRESETS
  *
  *  The next several routines do the immediate action pass on the command
- *  line options, then the environment variables then the RC files in
+ *  line options, then the environment variables, then the config files in
  *  reverse order.  Once done with that, the order is reversed and all
- *  the RC files and environment variables are processed again, this time
- *  only processing the non-immediate action options.  doPresets() will
- *  then return for optionProcess() to do the final pass on the command
+ *  the config files and environment variables are processed again, this
+ *  time only processing the non-immediate action options.  doPresets()
+ *  will then return for optionProcess() to do the final pass on the command
  *  line arguments.
  */
 
@@ -693,7 +695,7 @@ doImmediateOpts( tOptions* pOpts )
      *  are marked for immediate processing.
      */
     for (;;) {
-        tOptState optState = OPTSTATE_INITIALIZER;
+        tOptState optState = OPTSTATE_INITIALIZER(PRESET);
 
         switch (nextOption( pOpts, &optState )) {
         case FAILURE: goto optionsDone;
@@ -726,7 +728,7 @@ doRegularOpts( tOptions* pOpts )
      *  non-standard programs that require it.)
      */
     for (;;) {
-        tOptState optState = OPTSTATE_INITIALIZER;
+        tOptState optState = OPTSTATE_INITIALIZER(DEFINED);
 
         switch (nextOption( pOpts, &optState )) {
         case FAILURE: goto optionsDone;
@@ -754,137 +756,11 @@ doRegularOpts( tOptions* pOpts )
 
 
 /*
- *  doPresets - check for preset values from an rc file or the envrionment
+ *  doPresets - check for preset values from a config file or the envrionment
  */
-STATIC void
-doRcFiles( tOptions* pOpts )
-{
-    int     idx;
-    int     inc = DIRECTION_PRESET;
-    cch_t*  pzPath;
-    char    zFileName[ 4096 ];
-
-    /*
-     *  Find the last RC entry (highest priority entry)
-     */
-    for (idx = 0; pOpts->papzHomeList[ idx+1 ] != NULL; ++idx)  ;
-
-    /*
-     *  For every path in the home list, ...  *TWICE* We start at the last
-     *  (highest priority) entry, work our way down to the lowest priority,
-     *  handling the immediate options.
-     *  Then we go back up, doing the normal options.
-     */
-    for (;;) {
-        struct stat StatBuf;
-
-        /*
-         *  IF we've reached the bottom end, change direction
-         */
-        if (idx < 0) {
-            inc = DIRECTION_PROCESS;
-            idx = 0;
-        }
-
-        pzPath = pOpts->papzHomeList[ idx ];
-
-        /*
-         *  IF we've reached the top end, bail out
-         */
-        if (pzPath == NULL)
-            break;
-
-        idx += inc;
-
-        if (! optionMakePath( zFileName, sizeof( zFileName ),
-                              pzPath, pOpts->pzProgPath ))
-            continue;
-
-        /*
-         *  IF the file name we constructed is a directory,
-         *  THEN append the Resource Configuration file name
-         *  ELSE we must have the complete file name
-         */
-        if (stat( zFileName, &StatBuf ) != 0)
-            continue; /* bogus name - skip the home list entry */
-
-        if (S_ISDIR( StatBuf.st_mode )) {
-            size_t len = strlen( zFileName );
-            char* pz;
-
-            if (len + 1 + strlen( pOpts->pzRcName ) >= sizeof( zFileName ))
-                continue;
-
-            pz = zFileName + len;
-            if (pz[-1] != '/')
-                *(pz++) = '/';
-            strcpy( pz, pOpts->pzRcName );
-        }
-
-        filePreset( pOpts, zFileName, inc );
-
-        /*
-         *  IF we are now to skip RC files AND we are presetting,
-         *  THEN change direction.  We must go the other way.
-         */
-        if (SKIP_RC_FILES(pOpts) && PRESETTING(inc)) {
-            idx -= inc;  /* go back and reprocess current file */
-            inc =  DIRECTION_PROCESS;
-        }
-    } /* For every path in the home list, ... */
-}
-
-
-/*
- *  doPresets - check for preset values from an rc file or the envrionment
- */
-STATIC tSuccess
+static tSuccess
 doPresets( tOptions* pOpts )
 {
-    /*
-     *  IF the struct version is not the current, and also
-     *     either too large (?!) or too small,
-     *  THEN emit error message and fail-exit
-     */
-    if (  ( pOpts->structVersion  != OPTIONS_STRUCT_VERSION  )
-       && (  (pOpts->structVersion > OPTIONS_STRUCT_VERSION  )
-          || (pOpts->structVersion < OPTIONS_MINIMUM_VERSION )
-       )  )  {
-
-        fprintf( stderr, zAO_Err, pOpts->origArgVect[0],
-                 NUM_TO_VER( pOpts->structVersion ));
-        if (pOpts->structVersion > OPTIONS_STRUCT_VERSION )
-            fputs( zAO_Big, stderr );
-        else
-            fputs( zAO_Sml, stderr );
-
-        exit( EXIT_FAILURE );
-    }
-
-    /*
-     *  IF the client has enabled translation and the translation procedure
-     *  is available, then go do it.
-     */
-    if (  ((pOpts->fOptSet & OPTPROC_TRANSLATE) != 0)
-       && (pOpts->pTransProc != 0) ) {
-        (*pOpts->pTransProc)();
-    }
-
-    /*
-     *  when comparing long names, these are equivalent
-     */
-    strequate( zSepChars );
-
-    {
-        const char* pz = strrchr( *pOpts->origArgVect, '/' );
-
-        if (pz == NULL)
-             pOpts->pzProgName = *pOpts->origArgVect;
-        else pOpts->pzProgName = pz+1;
-
-        pOpts->pzProgPath = *pOpts->origArgVect;
-    }
-
     if (! SUCCESSFUL( doImmediateOpts( pOpts )))
         return FAILURE;
 
@@ -893,7 +769,7 @@ doPresets( tOptions* pOpts )
      */
     pOpts->fOptSet |= OPTPROC_PRESETTING;
     /*
-     *  IF there are no RC files,
+     *  IF there are no config files,
      *  THEN do any environment presets and leave.
      */
     if (  (pOpts->papzHomeList == NULL)
@@ -902,7 +778,7 @@ doPresets( tOptions* pOpts )
     }
     else {
         doEnvPresets( pOpts, ENV_IMM );
-        doRcFiles(    pOpts );
+        internalFileLoad( pOpts );
         doEnvPresets( pOpts, ENV_NON_IMM );
     }
     pOpts->fOptSet &= ~OPTPROC_PRESETTING;
@@ -917,7 +793,7 @@ doPresets( tOptions* pOpts )
  *
  *  Make sure that the argument list passes our consistency tests.
  */
-STATIC int
+static int
 checkConsistency( tOptions* pOpts )
 {
     int        errCt = 0;
@@ -966,23 +842,23 @@ checkConsistency( tOptions* pOpts )
         /*
          *  IF       this option is not equivalenced to another,
          *        OR it is equivalenced to itself (is the equiv. root)
-         *  THEN we need to make sure it occurrs often enough.
+         *  THEN we need to make sure it occurs often enough.
          */
         if (  (pOD->optEquivIndex == NO_EQUIVALENT)
            || (pOD->optEquivIndex == pOD->optIndex) )   do {
             /*
-             *  IF the occurrance counts have been satisfied,
+             *  IF the occurrence counts have been satisfied,
              *  THEN there is no problem.
              */
             if (pOD->optOccCt >= pOD->optMinCt)
                 break;
 
             /*
-             *  IF presetting is okay and it has been preset,
-             *  THEN min occurrance count doesn't count
+             *  IF MUST_SET means SET and PRESET are okay,
+             *  so min occurrence count doesn't count
              */
-#           define PRESET_OK  (OPTST_PRESET | OPTST_MUST_SET)
-            if ((pOD->fOptState & PRESET_OK) == PRESET_OK)
+            if (  (pOD->fOptState & OPTST_MUST_SET)
+               && (pOD->fOptState & (OPTST_PRESET | OPTST_SET)) )
                 break;
 
             errCt++;
@@ -1066,10 +942,13 @@ checkConsistency( tOptions* pOpts )
  * do not want to do this.
  *
  * The number of arguments processed always includes the program name.
- * If one of the arguments is "--", then it is counted and the
- * processing stops.  If an error was encountered and errors are
- * to be tolerated, then the returned value is the index of the
- * argument causing the error.
+ * If one of the arguments is "--", then it is counted and the processing
+ * stops.  If an error was encountered and errors are to be tolerated, then
+ * the returned value is the index of the argument causing the error.
+ * A hyphen by itself ("-") will also cause processing to stop and will
+ * @emph{not} be counted among the processed arguments.  A hyphen by itself
+ * is treated as an operand.  Encountering an operand stops option
+ * processing.
  *
  * err:  Errors will cause diagnostics to be printed.  @code{exit(3)} may
  *       or may not be called.  It depends upon whether or not the options
@@ -1082,6 +961,9 @@ optionProcess(
     int        argCt,
     char**     argVect )
 {
+    if (! SUCCESSFUL( validateOptionsStruct( pOpts, argVect[0] )))
+        exit( EXIT_FAILURE );
+
     /*
      *  Establish the real program name, the program full path,
      *  and do all the presetting the first time thru only.
@@ -1147,6 +1029,5 @@ optionProcess(
  * c-file-style: "stroustrup"
  * tab-width: 4
  * indent-tabs-mode: nil
- * tab-width: 4
  * End:
  * end of autoopts/autoopts.c */
