@@ -1,12 +1,13 @@
 
 /*
- *  $Id: guileopt.c,v 4.1 2005/01/01 00:12:40 bkorb Exp $
+ *  $Id: guileopt.c,v 4.6 2005/04/17 18:49:42 bkorb Exp $
+ * Time-stamp:      "2005-04-17 11:10:52 bkorb"
  *
  *  This module will export the option values to the Guile environment.
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -47,16 +48,13 @@
  * whether to permit this exception to apply to your modifications.
  * If you do not wish that, delete this exception notice.
  */
-
+#include "config.h"
 #include <stdio.h>
 #include <guile/gh.h>
 
-#include "options.h"
+#include "autoopts/options.h"
 #include "autoopts.h"
 
-/* === STATIC PROCS === */
-/* === END STATIC PROCS === */
-
 /*=export_func  export_options_to_guile
  * what:  put the option state into Guile symbols
  * private:
@@ -101,7 +99,7 @@ export_options_to_guile( pOpts )
          *  take numeric arguments will always have a value set.)
          */
         if (UNUSED_OPT( pOD )) {
-            if (pOD->fOptState & OPTST_NUMERIC) {
+            if (OPTST_GET_ARGTYPE(pOD->fOptState) == OPARG_TYPE_NUMERIC) {
                 sprintf( z, "(define opt-arg-%s %d)\n", pOD->pz_Name,
                          (uintptr_t)pOD->pzLastArg );
 #ifdef DEBUG
@@ -155,7 +153,7 @@ export_options_to_guile( pOpts )
         /*
          *  IF the option takes a numeric value, set the value
          */
-        else if (pOD->fOptState & OPTST_NUMERIC) {
+        else if (OPTST_GET_ARGTYPE(pOD->fOptState) == OPARG_TYPE_NUMERIC) {
             sprintf( z, "(define opt-arg-%s %d)\n", pOD->pz_Name,
                      (uintptr_t)pOD->pzLastArg );
 #ifdef DEBUG
