@@ -1,6 +1,7 @@
 
 /*
- *  $Id: pgusage.c,v 2.19 2004/02/02 03:31:51 bkorb Exp $
+ *  $Id: pgusage.c,v 4.4 2005/03/13 19:51:59 bkorb Exp $
+ * Time-stamp:      "2005-02-14 08:22:01 bkorb"
  *
  *   Automated Options Paged Usage module.
  *
@@ -9,7 +10,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -53,10 +54,7 @@
 
 tePagerState pagerState = PAGER_STATE_INITIAL;
 
-/* === STATIC PROCS === */
-/* === END STATIC PROCS === */
-
-/*=export_func  doPagedUsage
+/*=export_func  optionPagedUsage
  * private:
  *
  * what:  Decipher a boolean value
@@ -68,7 +66,7 @@ tePagerState pagerState = PAGER_STATE_INITIAL;
  *  This is very handy if it is very long.
 =*/
 void
-doPagedUsage( tOptions* pOptions, tOptDesc* pOD )
+optionPagedUsage( tOptions* pOptions, tOptDesc* pOD )
 {
     static pid_t     my_pid;
     char zPageUsage[ 1024 ];
@@ -101,7 +99,7 @@ doPagedUsage( tOptions* pOptions, tOptDesc* pOD )
         /*
          *  Set up so this routine gets called during the exit logic
          */
-        atexit( (void(*)(void))doPagedUsage );
+        atexit( (void(*)(void))optionPagedUsage );
 
         /*
          *  The usage procedure will now put the usage information into
