@@ -1,11 +1,11 @@
 
 /*
  *  columns.c
- *  $Id: columns.c,v 1.21 2003/12/20 19:52:40 bkorb Exp $
+ *  $Id: columns.c,v 4.4 2005/01/24 00:00:38 bkorb Exp $
  */
 
 /*
- *  Columns copyright 1992-2003 Bruce Korb
+ *  Columns copyright 1992-2005 Bruce Korb
  *
  *  Columns is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -34,9 +34,6 @@ struct print_list {
 
 typedef struct print_list tPrintList, *tpPrintList;
 
-typedef int (tCompProc)(const void*, const void*);
-tCompProc compProc;
-
 int maxEntryWidth = 0;
 int fillColumnCt  = 0;
 
@@ -52,11 +49,23 @@ size_t  lineWidth  = 79;
 size_t  columnCt   = 0;
 size_t  columnSz   = 0;
 
-void readLines( void );
-void writeRows( void );
-void writeColumns( void );
-int  handleIndent( tCC* pzIndentArg );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static int
+handleIndent( tCC* pzIndentArg );
 
+static void
+readLines( void );
+
+static void
+writeColumns( void );
+
+static void
+writeRows( void );
+
+static int
+compProc( const void* p1, const void* p2 );
+/* = = = END-STATIC-FORWARD = = = */
 
 int
 main( int    argc,
@@ -136,7 +145,7 @@ main( int    argc,
 }
 
 
-int
+static int
 handleIndent( tCC* pzIndentArg )
 {
     char* pz;
@@ -214,7 +223,7 @@ handleIndent( tCC* pzIndentArg )
 }
 
 
-void
+static void
 readLines( void )
 {
     int   sepLen;
@@ -365,7 +374,7 @@ readLines( void )
 }
 
 
-void
+static void
 writeColumns( void )
 {
     char zFmt[ 12 ];
@@ -508,7 +517,7 @@ writeColumns( void )
 }
 
 
-void
+static void
 writeRows( void )
 {
     char zFmt[ 12 ];
@@ -593,7 +602,7 @@ writeRows( void )
 /*
  *  Line comparison procedure
  */
-int
+static int
 compProc( const void* p1, const void* p2 )
 {
     const char* pz1 = *(char* const*)p1;
